==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/html/shadow/DataListButtonElement.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "HTMLDivElement.h"

namespace WebCore {

class TextFieldInputType;

class DataListButtonElement final : public HTMLDivElement {
    WTF_MAKE_TZONE_ALLOCATED(DataListButtonElement);
    WTF_OVERRIDE_DELETE_FOR_CHECKED_PTR(DataListButtonElement);
public:
    class DataListButtonOwner {
    public:
        virtual ~DataListButtonOwner() = default;
        virtual void dataListButtonElementWasClicked() = 0;
    };

    ~DataListButtonElement();

    static Ref<DataListButtonElement> create(Document&, DataListButtonOwner&);

    bool canAdjustStyleForAppearance() const;

private:
    explicit DataListButtonElement(Document&, DataListButtonOwner&);

    bool isDataListButtonElement() const override { return true; }

    void defaultEventHandler(Event&) override;
    bool isDisabledFormControl() const override;

    DataListButtonOwner& m_owner;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::DataListButtonElement)
    static bool isType(const WebCore::HTMLElement& element) { return element.isDataListButtonElement(); }
    static bool isType(const WebCore::Node& node)
    {
        auto* htmlElement = dynamicDowncast<WebCore::HTMLElement>(node);
        return htmlElement && isType(*htmlElement);
    }
SPECIALIZE_TYPE_TRAITS_END()

==> webkit2gtk_2.51.92.orig.tar.xz: webkitgtk-2.51.92/Source/WebCore/html/shadow/DataListButtonElement.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "HTMLDivElement.h"

namespace WebCore {

class TextFieldInputType;

class DataListButtonElement final : public HTMLDivElement {
    WTF_MAKE_TZONE_ALLOCATED(DataListButtonElement);
    WTF_OVERRIDE_DELETE_FOR_CHECKED_PTR(DataListButtonElement);
public:
    class DataListButtonOwner {
    public:
        virtual ~DataListButtonOwner() = default;
        virtual void dataListButtonElementWasClicked() = 0;
    };

    ~DataListButtonElement();

    static Ref<DataListButtonElement> create(Document&, DataListButtonOwner&);

    bool canAdjustStyleForAppearance() const { return m_canAdjustStyleForAppearance; }

private:
    explicit DataListButtonElement(Document&, DataListButtonOwner&);

    bool isDataListButtonElement() const final { return true; }
    std::optional<Style::UnadjustedStyle> resolveCustomStyle(const Style::ResolutionContext&, const RenderStyle* shadowHostStyle) final;

    void defaultEventHandler(Event&) override;
    bool isDisabledFormControl() const override;

    DataListButtonOwner& m_owner;
    bool m_canAdjustStyleForAppearance { true };
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::DataListButtonElement)
    static bool isType(const WebCore::HTMLElement& element) { return element.isDataListButtonElement(); }
    static bool isType(const WebCore::Node& node)
    {
        auto* htmlElement = dynamicDowncast<WebCore::HTMLElement>(node);
        return htmlElement && isType(*htmlElement);
    }
SPECIALIZE_TYPE_TRAITS_END()
